@@ -222,7 +222,12 @@ def import_sql(db, output, **args):
 @click.option('--max-enum-size', default=50, help='do not create an enum if more than max distinct members')
 @click.option('--enum-threshold', default=0.1, help='if the number of distinct values / rows is less than this, do not make an enum')
 @click.option('--omit-null/--no-omit-null', default=False, help="if true, ignore null values")
-def generalize_json(input, output, schema_name, format, omit_null, **kwargs):
+@click.option('--inlined-map', multiple=True, help="SLOT_NAME.KEY pairs indicating which slots are inlined as dict")
+@click.option('--depluralize/--no-depluralized',
+              default=True,
+              show_default=True,
+              help="Auto-depluralize class names to singular form")
+def generalize_json(input, output, schema_name, depluralize: bool, format, omit_null, inlined_map, **kwargs):
     """
     Generalizes from a JSON file to a schema
 
@@ -232,7 +237,9 @@ def generalize_json(input, output, schema_name, format, omit_null, **kwargs):
 
         schemauto generalize-json my/data/persons.json -o my.yaml
     """
-    ie = JsonDataGeneralizer(omit_null=omit_null)
+    ie = JsonDataGeneralizer(omit_null=omit_null, depluralize_class_names=depluralize)
+    if inlined_map:
+        ie.inline_as_dict_slot_keys = dict([tuple(x.split(".")) for x in inlined_map])
     schema = ie.convert(input, format=format, **kwargs)
     write_schema(schema, output)
 
@@ -345,13 +352,31 @@ def annotate_schema(schema: str, input: str, output: str, **kwargs):
     """
     Annotate all elements of a schema
 
-    This uses OAK, and you can provide any OAK backend. See:
+    This uses OAK (https://incatools.github.io/ontology-access-kit),
+    and you can provide any OAK backend that supports text annotation.
+    
+    At this time, the best choice is likely the bioportal backend
+    
+    Example:
+    
+        schemauto annotate-schema -i bioportal: my-schema.yaml -o annotated.yaml
+        
+    This will require you setting the API key via OAK - see OAK docs.
+        
+    You can specify a specific ontology
+    
+        schemauto annotate-schema -i bioportal:ncbitaxon my-schema.yaml -o annotated.yaml
 
-    `Selectors <https://incatools.github.io/ontology-access-kit/selectors.html>`_
+    In future OAK will support a much wider variety of annotators including:
+    
+       - OLS
+       - SciSpacy
+       - NLTK
+       - OGER
 
-    Note:
-
-        if you provide "bioportal" as selector, you must have set your API key uising OAK
+    To see all possible selectors, see the OAK docs:
+    
+      - https://incatools.github.io/ontology-access-kit/selectors.html
     """
     impl = get_implementation_from_shorthand(input)
     annr = SchemaAnnotator(impl, **kwargs)
